/*
 * HFS (aka MAC) filesystem/handler for MorphOS/AmigaOS
 * Author: Marek 'March' Szyprowski <marek@amiga.pl>
 */

#ifndef __MACFS_HANDLER_INLINES_H
#define __MACFS_HANDLER_INLINES_H

static inline LONG TestLock(struct ExtFileLock *fl)
{
	if (fl == 0 && glob->sb == NULL)
	{
		if (glob->disk_inserted == FALSE)
			return ERROR_NO_DISK;
		else
			return ERROR_NOT_A_DOS_DISK;
	}
 
	if (glob->sb == NULL || glob->disk_inhibited || (fl && TypeOfMem(fl) && fl->fl_Volume != MKBADDR(glob->sb->doslist)))
		return ERROR_DEVICE_NOT_MOUNTED;

	if (fl && (TypeOfMem(fl) == 0 || fl->magic != ID_HFS_DISK))
		return ERROR_OBJECT_WRONG_TYPE;

	return 0;
}

static inline ULONG WriteCheck()
{
	if (glob->sb->read_only != 0 || GetDiskProtectionStatus() == ID_WRITE_PROTECTED)
		return ERROR_WRITE_PROTECTED;
	return 0;
}

static inline LONG IsRootLock(struct ExtFileLock *fl)
{
	return fl->fl_Key == HFS_CNID_ROOTDIR;
}

#define SkipColon(name, namelen) {		 \
	int i;                      		 \
	for (i=0; i<namelen; i++)   		 \
		if (name[i] == ':')     		 \
		{                       		 \
			namelen = namelen - (i+1);   \
			name = &name[i+1];  		 \
			break;              		 \
		}                       		 \
}

#define SplitLastPart(path, pathlen, name, namelen) {           \
	name = path + pathlen;                                      \
	namelen = 0;                                                \
	while (name > path && *(name-1) != '/' && *(name-1) != ':') \
	{                                                           \
		name--;                                                 \
		namelen++;                                              \
	}                                                           \
	pathlen -= namelen;											\
}


/* Mem... */

static inline void *FS_AllocMem(ULONG bytes)
{
#ifdef __DEBUG_MEM__
	kprintf("\tFS_AllocMem %ld\n", bytes);
#endif
	return AllocVecPooled(glob->mempool, bytes);
}

static inline void FS_FreeMem(void *mem)
{
#ifdef __DEBUG_MEM__
	kprintf("\tFS_FreeMem %08lx\n", (LONG) mem);
#endif
	FreeVecPooled(glob->mempool, mem);
}

#endif

